#include <itkImage.h>
#include <itkImageFileReader.h>
#include <itkImageFileWriter.h>
#include <itkStochasticFractalDimensionImageFilter.h>


void showUsage(std::string str)
{
	std::cout << "Usage:\n"
	<< "\t" << str << "\n"
	<< "\tinputImage\n"
	<< "\toutputImage\n"
	<< "\t[radius, default = 2]\n";
}



int main(int argc, char **argv)
{
	if(argc < 3)
	{
		showUsage(argv[0]);
		return -1;
	}

	// Get inputs from command line
	std::string inputFileName, outputFileName;
	inputFileName = argv[1];
	outputFileName = argv[2];
	int radius = argc > 3 ? atoi(argv[3]) : 2;

	// Dimension and pixel type
	const int Dimension = 2;
	typedef unsigned char PixelType;

	// Image and reader/writer definitions
	typedef itk::Image< PixelType, Dimension > ImageType;
	typedef itk::ImageFileReader< ImageType > ReaderType;
	typedef itk::ImageFileWriter< ImageType > WriterType;

	// Read input
	ReaderType::Pointer reader = ReaderType::New();
	reader->SetFileName(inputFileName);
	reader->Update();

	// Filter definition
	typedef itk::StochasticFractalDimensionImageFilter< ImageType > StochasticFractalDimensionImageFilterType;
	StochasticFractalDimensionImageFilterType::Pointer stochastic_filter = StochasticFractalDimensionImageFilterType::New();

	// Set filter input
	stochastic_filter->SetInput(reader->GetOutput());

	// Set radius
	ImageType::SizeType r;
	r.Fill(radius);
	stochastic_filter->SetNeighborhoodRadius(r);
	
	// Do it
	stochastic_filter->Update();

	// Write output to file
	WriterType::Pointer writer = WriterType::New();
	writer->SetFileName(outputFileName);
	writer->SetInput(stochastic_filter->GetOutput());
	writer->Update();

	return 0;
}